MethodChannelFirebasePnv class

An implementation of FirebasePnvPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFirebasePnv()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkSupport() → Future<bool>
Checks whether the current device and SIM card(s) support Firebase Phone Number Verification (PNV).
override
enableTestSession(String token) → Future<void>
Enables a Firebase PNV test session using a token generated from the Firebase console's Security > Phone Verification > Testing tab.
override
getVerifiedPhoneNumber() → Future<Map<String, dynamic>?>
Runs the full Firebase PNV verification flow.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited