registerWith static method
void
registerWith()
Registers this class as the default instance of FirebasePnvPlatform.
Implementation
static void registerWith() {
FirebasePnvPlatform.instance = FirebasePnvLinux();
}
Registers this class as the default instance of FirebasePnvPlatform.
static void registerWith() {
FirebasePnvPlatform.instance = FirebasePnvLinux();
}