FirebasePnvWindows class
Windows stub implementation of the firebase_pnv plugin.
- Inheritance
-
- Object
- PlatformInterface
- FirebasePnvPlatform
- FirebasePnvWindows
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkSupport(
) → Future< bool> -
Checks whether the current device and SIM card(s) support Firebase
Phone Number Verification (PNV).
override
-
enableTestSession(
String token) → Future< void> -
Enables a Firebase PNV test session using a token generated from the
Firebase console's Security > Phone Verification > Testing tab.
override
-
getVerifiedPhoneNumber(
) → Future< Map< String, dynamic> ?> -
Runs the full Firebase PNV verification flow.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void - Registers this class as the default instance of FirebasePnvPlatform.